<?php
/**
 * Custom template tags for Femina
 *
 * @package Femina
 * @since Femina 1.0.7
 */


/**
 * Prints Femina's custom logo markup.
 * @since Femina 1.0.7
 */
function femina_the_custom_logo() {
	$html = sprintf( '<a href="%1$s" class="custom-logo-link home-link" rel="home" itemprop="url"><img class="custom-logo" src="%2$s" alt="logo"><div class="title-description"><h1 class="site-title">%3$s</h1><h2 class="site-description">%4$s</h2></div></a>',
		esc_url( home_url( '/' ) ),
		esc_attr(wp_get_attachment_image_url(get_theme_mod('custom_logo'), 'full') ),
		esc_html( get_bloginfo( 'name') ) ,
		esc_html( get_bloginfo( 'description') ) );

    return $html;
}
add_filter('get_custom_logo', 'femina_the_custom_logo');

/**
 * Changes the default strings for the_posts_pagination().
 * @since Femina 1.0.7
 */
function femina_posts_pagination() {
	the_posts_pagination( array(
		'prev_text' 			=> '<span class="screen-reader-text">'.__( 'Newer articles', 'femina' ).'</span>',
		'next_text' 			=> '<span class="screen-reader-text">'.__( 'Older articles', 'femina' ).'</span>',
		'before_page_number' 	=> '<span class="meta-nav screen-reader-text">' . __( 'Page', 'femina' ) . ' </span>',
		) );
}
/**
 * Changes the default strings for the_post_navigation().
 * @since Femina 1.0.7
 */
function femina_post_navigation() {
	the_post_navigation( array(
		'next_text' => 	'<span class="post-title">%title</span>' .
						'<span class="screen-reader-text">' . __( 'Next post:', 'femina' ) . '</span> ' .
						'<span class="meta-nav" aria-hidden="true">&rarr;</span> ',
		'prev_text' =>  '<span class="meta-nav" aria-hidden="true">&larr;</span> ' .
						'<span class="screen-reader-text">' . __( 'Previous post:', 'femina' ) . '</span> ' .
						'<span class="post-title">%title</span>',
	) );
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ...
 * and a Continue reading link.
 *
 * @since Femina 1.0.7
 *
 * @param string $more Default Read More excerpt link.
 * @return string Filtered Read More excerpt link.
 */
function femina_excerpt_more( $more ) {
	if ( ! is_single() ) {
		$link = sprintf( '<a href="%1$s" class="more-link">%2$s</a>',
		esc_url( get_permalink( get_the_ID() ) ),
			/* Translators: %s: Name of current post */
			sprintf( __( 'More', 'femina' ).' %s <span class="meta-nav">&rarr;</span>', '<span class="screen-reader-text">' . get_the_title( get_the_ID() ) . '</span>' )
		);
	return ' &hellip; ' . $link;
	}

	else{
		return '. ';
	}
}
add_filter( 'excerpt_more', 'femina_excerpt_more' );

/**
 * Filter the except length to 20 characters.
 *
 * @param int $length Excerpt length.
 * @return int (Maybe) modified excerpt length.
 */
function femina_excerpt_length( $length ) {
   return 20;
}
add_filter( 'excerpt_length', 'femina_excerpt_length', 999 );

